## Cool References

### Defining class properties in python
- https://stackoverflow.com/a/2627034
- https://www.geeksforgeeks.org/getter-and-setter-in-python/

### Defining a timer class
- https://realpython.com/python-timer/

### Notes on Python Packaging
- https://packaging.python.org/en/latest/tutorials/packaging-projects/

### Saving Matrix Animations
- https://stackoverflow.com/a/69018855
  - Didn't work for me
- https://stackoverflow.com/a/25143651
  - Also didn't work
- https://stackoverflow.com/a/9890599
  - Saving matplotlib figure as picture
- https://stackoverflow.com/a/35943809
  - Compiling pictures into a GIF
  - https://imageio.readthedocs.io/en/stable/_autosummary/imageio.v2.mimwrite.html
    - official docs

### Finding pairs between numbers
- https://www.geeksforgeeks.org/python-all-possible-pairs-in-list/

### Hill-climbing algorithms
- https://www.geeksforgeeks.org/introduction-hill-climbing-artificial-intelligence/
